@@ -295,11 +295,11 @@ def transform_offer_attr(offer_attr):
 
 # Main functions
 
-def load_model(model_path, model_name, model_prefix, model_epoch, context_lookup_names, sequence_lookup_name):
+def load_model(model_dir, model_name, model_prefix, model_epoch, context_lookup_names, sequence_lookup_name):
     # lookup tables
-    model_path = os.path.join(model_path, model_name, model_prefix)
+    model_path = os.path.join(model_dir, model_name, model_prefix)
     lookup_paths = {
-        k: os.path.join(model_path, model_name, k + "_lookup.csv") for k in context_lookup_names + [sequence_lookup_name]
+        k: os.path.join(model_dir, model_name, k + "_lookup.csv") for k in context_lookup_names + [sequence_lookup_name]
     }
     lookup_tables = {
         k: pd.read_csv(lookup_paths[k]) for k in context_lookup_names + [sequence_lookup_name]
